@@ -29,7 +29,6 @@ use uuid::Uuid;
 use crate::metrics::vectors::MergeSource;
 use crate::prelude::*;
 use crate::query_language::BooleanExpression;
-use crate::Channel;
 use crate::IndexFiles;
 use nucliadb_protos::noderesources;
 
@@ -38,6 +37,8 @@ pub type VectorsWriterPointer = Box<dyn VectorWriter>;
 pub type ProtosRequest = nodereader::VectorSearchRequest;
 pub type ProtosResponse = nodereader::VectorSearchResponse;
 
+pub const SEGMENT_TAGS: &[&str] = &["/q/h"];
+
 #[derive(Debug, Clone, Copy)]
 pub struct MergeParameters {
     pub max_nodes_in_merge: usize,
@@ -54,7 +55,6 @@ pub struct MergeContext {
 pub struct VectorIndexConfig {
     pub similarity: utils::VectorSimilarity,
     pub path: PathBuf,
-    pub channel: Channel,
     pub shard_id: String,
     pub normalize_vectors: bool,
 }
@@ -65,6 +65,7 @@ pub struct VectorIndexConfig {
 #[derive(Clone, Default)]
 pub struct VectorsContext {
     pub filtering_formula: Option<BooleanExpression>,
+    pub segment_filtering_formula: Option<BooleanExpression>,
 }
 
 pub struct MergeMetrics {
@@ -137,6 +138,10 @@ impl<'a> ResourceWrapper<'a> {
         &self.resource.shard_id
     }
 
+    pub fn labels(&self) -> &[String] {
+        &self.resource.labels
+    }
+
     pub fn fields(&self) -> impl Iterator<Item = (&String, impl Iterator<Item = ParagraphVectors>)> {
         self.resource.paragraphs.iter().map(|(field_id, paragraphs_wrapper)| {
             let sentences_iterator = paragraphs_wrapper.paragraphs.iter().filter_map(|(_paragraph_id, paragraph)| {
