@@ -33,6 +33,7 @@ use nucliadb_core::protos::{
     ShardFile, ShardFileChunk, ShardFileList, StreamRequest, SuggestFeatures, SuggestRequest, SuggestResponse,
     VectorSearchRequest, VectorSearchResponse,
 };
+use nucliadb_core::query_language;
 use nucliadb_core::query_language::BooleanExpression;
 use nucliadb_core::query_language::BooleanOperation;
 use nucliadb_core::query_language::Operator;
@@ -75,7 +76,7 @@ fn open_paragraphs_reader(version: u32, path: &Path) -> NodeResult<ParagraphsRea
 
 fn open_texts_reader(version: u32, path: &Path) -> NodeResult<TextsReaderPointer> {
     match version {
-        2 => nucliadb_texts2::reader::TextReaderService::open(path).map(|i| Box::new(i) as TextsReaderPointer),
+        3 => nucliadb_texts3::reader::TextReaderService::open(path).map(|i| Box::new(i) as TextsReaderPointer),
         v => Err(node_error!("Invalid text reader version {v}")),
     }
 }
@@ -155,6 +156,7 @@ impl ShardReader {
             0 => DocumentService::DocumentV0,
             1 => DocumentService::DocumentV1,
             2 => DocumentService::DocumentV2,
+            3 => DocumentService::DocumentV3,
             i => panic!("Unknown document version {i}"),
         }
     }
@@ -227,7 +229,7 @@ impl ShardReader {
         Ok(Shard {
             metadata: Some(protos::ShardMetadata {
                 kbid: self.metadata.kbid(),
-                release_channel: self.metadata.channel() as i32,
+                release_channel: 0,
             }),
             shard_id: self.id.clone(),
             // naming issue here, this is not number of resource
@@ -370,22 +372,36 @@ impl ShardReader {
         // Prefilter to apply field label filters
         if let Some(filter) = &mut request.filter {
             if !filter.field_labels.is_empty() && suggest_paragraphs {
-                let labels = std::mem::take(&mut filter.field_labels);
-                let operands = labels.into_iter().map(BooleanExpression::Literal).collect();
-                let op = BooleanOperation {
-                    operator: Operator::And,
-                    operands,
+                let labels_formula = if filter.labels_expression.is_empty() {
+                    // Backwards compatibility, take all labels to be AND'ed together
+                    let labels = std::mem::take(&mut filter.field_labels);
+                    let operands = labels.into_iter().map(BooleanExpression::Literal).collect();
+                    let op = BooleanOperation {
+                        operator: Operator::And,
+                        operands,
+                    };
+
+                    Some(BooleanExpression::Operation(op))
+                } else {
+                    // Parse the formula for labels, suggest only supports resource labels
+                    let context = query_language::QueryContext {
+                        field_labels: filter.field_labels.iter().cloned().collect(),
+                        paragraph_labels: HashSet::new(),
+                    };
+                    let analysis = query_language::translate(Some(&filter.labels_expression), None, &context)?;
+                    analysis.labels_prefilter_query
                 };
+
                 let prefilter = PreFilterRequest {
                     timestamp_filters: vec![],
                     security: None,
-                    labels_formula: Some(BooleanExpression::Operation(op)),
+                    labels_formula,
                     keywords_formula: None,
                 };
 
                 let prefiltered = read_rw_lock(&self.text_reader).prefilter(&prefilter)?;
 
-                // Apply prefilter to paragraphs query
+                // Apply prefilter to paragraphs query and clear filters
                 match prefiltered.valid_fields {
                     query_planner::ValidFieldCollector::All => {}
                     query_planner::ValidFieldCollector::Some(keys) => {
@@ -393,6 +409,8 @@ impl ShardReader {
                     }
                     query_planner::ValidFieldCollector::None => suggest_paragraphs = false,
                 }
+                filter.labels_expression.clear();
+                filter.field_labels.clear();
             }
         }
 
