@@ -37,7 +37,7 @@ use super::indexes::{ShardIndexes, DEFAULT_VECTORS_INDEX_NAME};
 use super::metadata::ShardMetadata;
 use super::versioning::{self, Versions};
 use crate::disk_structure::{self, *};
-use crate::settings::{feature_flags, Settings};
+use crate::settings::Settings;
 use crate::telemetry::run_with_telemetry;
 
 const MAX_LABEL_LENGTH: usize = 32768; // Tantivy max is 2^16 - 4
@@ -106,7 +106,7 @@ impl ShardWriter {
     }
 
     #[measure(actor = "shard", metric = "new")]
-    pub fn new(new: NewShard, shards_path: &Path, settings: &Settings) -> NodeResult<(Self, Arc<ShardMetadata>)> {
+    pub fn new(new: NewShard, shards_path: &Path, _settings: &Settings) -> NodeResult<(Self, Arc<ShardMetadata>)> {
         let span = tracing::Span::current();
 
         if new.vector_configs.is_empty() {
@@ -120,14 +120,6 @@ impl ShardWriter {
 
         std::fs::create_dir(&shard_path)?;
 
-        let ff_context = HashMap::from([("kbid".to_string(), metadata.kbid())]);
-        let texts3_enabled = settings.has_feature(feature_flags::TEXTS3, ff_context);
-        let texts_version = if texts3_enabled {
-            3
-        } else {
-            2
-        };
-
         let versions = Versions {
             paragraphs: versioning::PARAGRAPHS_VERSION,
             vectors: versioning::VECTORS_VERSION,
@@ -142,7 +134,7 @@ impl ShardWriter {
         let tsc = TextConfig {
             path: indexes.texts_path(),
         };
-        let text_task = || Some(create_texts_writer(texts_version, tsc));
+        let text_task = || Some(create_texts_writer(versioning::TEXTS_VERSION, tsc));
         let info = info_span!(parent: &span, "text start");
         let text_task = || run_with_telemetry(info, text_task);
 
@@ -617,14 +609,12 @@ impl ShardWriter {
 
         segments.insert("paragraph".to_string(), indexes.paragraphs_index.get_segment_ids()?);
         segments.insert("text".to_string(), indexes.texts_index.get_segment_ids()?);
-        // TODO: return segments for all vector indexes
-        let default_vectors_index = indexes
-            .vectors_indexes
-            .get(DEFAULT_VECTORS_INDEX_NAME)
-            .expect("Default vectors index should never be deleted (yet)");
-        segments.insert("vector".to_string(), default_vectors_index.get_segment_ids()?);
         segments.insert("relation".to_string(), indexes.relations_index.get_segment_ids()?);
 
+        for (key, index) in &indexes.vectors_indexes {
+            segments.insert(format!("vector-{key}"), index.get_segment_ids()?);
+        }
+
         Ok(segments)
     }
 
@@ -648,7 +638,7 @@ impl ShardWriter {
                     path.clone(),
                     index.get_index_files(
                         path.to_str().unwrap(),
-                        ignored_segment_ids.get("vector").unwrap_or(&Vec::new()),
+                        ignored_segment_ids.get(&format!("vector-{key}")).unwrap_or(&Vec::new()),
                     )?,
                 ));
             }
@@ -696,7 +686,6 @@ pub fn open_paragraphs_writer(version: u32, config: &ParagraphConfig) -> NodeRes
 
 pub fn open_texts_writer(version: u32, config: &TextConfig) -> NodeResult<TextsWriterPointer> {
     match version {
-        2 => nucliadb_texts2::writer::TextWriterService::open(config).map(|i| Box::new(i) as TextsWriterPointer),
         3 => nucliadb_texts3::writer::TextWriterService::open(config).map(|i| Box::new(i) as TextsWriterPointer),
         v => Err(node_error!("Invalid text writer version {v}")),
     }
@@ -704,7 +693,6 @@ pub fn open_texts_writer(version: u32, config: &TextConfig) -> NodeResult<TextsW
 
 pub fn create_texts_writer(version: u32, config: TextConfig) -> NodeResult<TextsWriterPointer> {
     match version {
-        2 => nucliadb_texts2::writer::TextWriterService::create(config).map(|i| Box::new(i) as TextsWriterPointer),
         3 => nucliadb_texts3::writer::TextWriterService::create(config).map(|i| Box::new(i) as TextsWriterPointer),
         v => Err(node_error!("Invalid text writer version {v}")),
     }
