@@ -20,7 +20,7 @@ use std::collections::HashMap;
 use std::time::SystemTime;
 
 use nucliadb_core::protos::prost_types::Timestamp;
-use nucliadb_core::{Channel, NodeResult};
+use nucliadb_core::NodeResult;
 use nucliadb_protos::nodereader;
 use nucliadb_protos::noderesources;
 use nucliadb_vectors::config::{Similarity, VectorConfig};
@@ -28,6 +28,7 @@ use tempfile;
 use uuid::Uuid;
 
 use crate::disk_structure;
+use crate::settings::EnvSettings;
 use crate::shards::indexes::DEFAULT_VECTORS_INDEX_NAME;
 use crate::shards::reader::ShardReader;
 
@@ -41,14 +42,15 @@ fn test_vectorsets() -> NodeResult<()> {
     let shard_id = "shard".to_string();
     let kbid = "kbid".to_string();
 
+    let settings = EnvSettings::default().into();
     let (writer, _metadata) = ShardWriter::new(
         crate::shards::writer::NewShard {
             kbid: kbid.clone(),
             shard_id: shard_id.clone(),
-            channel: Channel::default(),
             vector_configs: HashMap::from([(DEFAULT_VECTORS_INDEX_NAME.to_string(), VectorConfig::default())]),
         },
         &shards_path,
+        &settings,
     )?;
     writer.create_vectors_index(
         "myvectorset".to_string(),
