@@ -87,15 +87,9 @@ impl ParagraphWriter for ParagraphWriterService {
         debug!("{id:?} - Processing paragraphs to delete: starts at {v} ms");
 
         // Delete all paragraphs matching the field_uuid
-        //
-        // Bw/c delete by paragraph_id
         for field_or_paragraph_id in &resource.paragraphs_to_delete {
             let field_uuid_term = Term::from_field_text(self.schema.field_uuid, field_or_paragraph_id);
             self.writer.delete_term(field_uuid_term);
-            // TODO: remove deletion by paragraph_id when deletion by field gets
-            // promoted
-            let paragraph_uuid_term = Term::from_field_text(self.schema.paragraph, field_or_paragraph_id);
-            self.writer.delete_term(paragraph_uuid_term);
         }
 
         self.writer.commit()?;
